//******************************************************************************
//  MSP-430-Day II Demo - DMA0 Repeated Block To P1OUT, TACCR2, DCO
//
//  Description; DMA0 is used to transfer a string byte-by-byte as a repeating
//  block to P1OUT. Timer_A operates Continuously clocked at ~800Hz with CCR2IFG 
//  triggering DMA0. The effect is P1.0 toggling at different frequencies. 
//  ACLK = 32768, MCLK = SMCLK =  TACLK = default DCO = 1048576
//  //*An external watch crystal on XIN XOUT is required for ACLK*//	  
//  //*MSP430FG439 Device Required*//
//
//               MSP430FG439
//            -----------------
//        /|\|              XIN|-  
//         | |                 | 32KHz
//         --|RST          XOUT|-
//           |                 |
//           |             P1.0|--> LED 
//
//  M.Buccini
//  Texas Instruments, Inc
//  February 2004
//  Updated for IAR Embedded Workbench Version: 2.21B
//******************************************************************************

#include  <msp430xG43x.h>

const char testconst[] = { 0x01, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00 , 0x00};

void main(void)
{
  WDTCTL = WDTPW + WDTHOLD;                           // Stop watchdog
  FLL_CTL0 |= XCAP14PF;                               // Set load capacitance
  P1DIR |= 0x01;                                      // P1.0 = output 
  DMACTL0 = DMA0TSEL_1;                               // CCR2IFG trigger
  DMA0SA = (unsigned int)testconst;                   // Src block address
  DMA0DA = P1OUT_;                                    // Dst single address
  DMA0SZ = sizeof testconst;                          // Block size
  DMA0CTL = DMADT_4 + DMASRCINCR_3 + DMASBDB + DMAEN; // Rpt, inc src, enable
  TACTL = TASSEL_2 + ID_2 + MC_2;                     // SMCLK, /4, cont-mode
       
  _BIS_SR(LPM0_bits + GIE);                           // Enter LPM0, w/ int
}


